* **I'm submitting a ... **
  - [ ] bug report
  - [ ] feature request
  - [ ] support request


* **Do you want to request a *feature* or report a *bug*?**



* **What is the current behavior?**



* **If the current behavior is a bug, please provide the steps to reproduce and if possible a minimal demo of the problem



* **What is the expected behavior?**



* **What is the motivation / use case for changing the behavior?**



* **Please tell us about your environment:**

- Release Number of the Repository used : 
- Python Version : 
- OS, OS Version : 



* **Other information** (e.g. detailed explanation, stack traces, related issues, suggestions how to fix, links for us to have context, eg. stackoverflow
, gitter, etc)
